=======
History
=======

0.0.1 (08-22-2019)
------------------

* First release on PyPI.

0.0.2 (08-23-2019)
------------------

* Addition of Cytoscape functionality.

0.0.3 (08-26-2019)
------------------

* Improvements to the plots produced by the continuity analysis.

0.0.4 (09-5-2019)
------------------

* Addition of automatically generated physiological bounds for optimization routines.
* Addition of safety precautions for numerical continuation.